function [X, N] = multinewton(funcx, x0, tol)
% Funkcija za rjesavanje sustava nelinearnih jednadzbi primjenom 
% Newtonove metode
% Poziv funkcije: [X, N] = multinewton(funcx, x0, tol) gdje su
% X - izlaz --> rjesenja sustava jednadzbi
% N - izlaz --> broj iteracija Newtonove metode
% funcx - ulaz --> M-funkcija u kojoj su definirane jednadzbe sustava
% x0 - ulaz --> pocetne iteracije
% tol - ulaz --> tolerancija pogreske

N = 0;
X = x0;
err = 1;

while err > tol
    Ja_x = jacobian_complex(funcx, X);
    f = feval(funcx, X);
    XX = X - Ja_x\f;
    err = norm(XX-X);
    N = N + 1;
    X = XX;
end


